<%@page contentType="text/javascript" session="false"%>
document.write('<script src="<%= request.getContextPath() %>/js/dojo/dojo.js"></script>');

function getWebFeed(url, container, showAbstracts, maxFeeds, showDate) {
	if (maxFeeds == undefined) {
		maxFeeds = 5;
	}

	if (getWebFeedListDiv(container)) {
		toggleWebFeedListDiv(container);
	} else if(getWebFeedErr(container)) {
		removeWebFeedErr(container);
	} else if (!isLoading(container)) {
		toggleWebFeedListDiv(container);
		showLoadingIndicator(container);
		var args = {
	     url: "<%= request.getContextPath() %>/api/webfeed",
	     content: {
			url: url,
			count: maxFeeds
	     },
	     load: function(store) {
	     	writeWebFeed(store, container, showAbstracts, showDate);
	     },
	     error: function(err){
			writeWebFeedErr(container, err, "p");
	     },
	     handle: function(){ //general executor at the end
	     	hidLoadingIndicator(container);
	     }	     
	   };
	   args.handleAs = "json";
	   dojo.xhrGet(args);
	}	
}

<%--
 * Write the Feed out to the page
 * 
 * STEPS
 * 
 * (1) Add the <div class="webfeed-list-div">  child.
 * 
 *      <div class="webfeed-list-div">
 *        <ul class="webfeed-link-list">
 * 		   <li><a target="_blank" href="http://example.com/article.html" >Item 1 title</a></li>
 * 		   <li><a target="_blank" href="http://example.com/article.html" >Item 1 title</a></li>
 * 		   <li><a target="_blank" href="http://example.com/article.html" >Item 1 title</a></li>
 * 		  </ul>
 * 		  <p class="webfeed-subscribe"><a target="_blank" href="http://example.com/rss">XML</a></p>
 * 		</div>
 *
 * (2) Modify class attribute on
	<a class="webfeed-link" .. to
		<a class="webfeed-link-open" to indicate that is open
 * 
 --%>
function writeWebFeed(store, container, showAbstracts, showDate) {
	if (store != null && store.items) {
		var items = store.items;
		var div = document.createElement("div");
		div.setAttribute("class", "webfeed-list-div");
		var ul = document.createElement("ul");
		ul.setAttribute("class", "webfeed-link-list");
		div.appendChild(ul);
		container.parentNode.appendChild(div);
		
		dojo.forEach(items, dojo.hitch(this, function(item){
			var title = item.title;
			var href = item.link;
			var li = document.createElement("li");
			var a = document.createElement("a");
			a.setAttribute("target", "_blank");
			a.setAttribute("href", href);
			a.appendChild(document.createTextNode(title));
			li.appendChild(a);
			
			if (showDate && item.pubDate != null) {
				var dateDiv = document.createElement("div");
				dateDiv.setAttribute("style", "position: relative; color: grey; bottom: 5px; font-size: 0.9em; line-height: 150%");
			
				var dateNode = document.createTextNode(item.pubDate);
				dateDiv.appendChild(dateNode);
				li.appendChild(dateDiv);
			}

			if (showAbstracts && item.description != null) {
				var abstractDiv = document.createElement("div");
				abstractDiv.setAttribute("class", "utErrorDialogFeedAbstract");
			
				var abstractNode = document.createTextNode(item.description);
				abstractDiv.appendChild(abstractNode);
				li.appendChild(abstractDiv);
			}
			
			ul.appendChild(li);
		}));
		resizeKCFrame();
	}
}

function toggleWebFeedListDiv(container) {
	var linkClosed = this.getElementByClassName(container, "webfeed-link");
	var linkOpen = this.getElementByClassName(container, "webfeed-link-open");
	var div = getWebFeedListDiv(container);
	if (div) {
	    if (dojo.style(div, "display") == "none"){
	        dojo.style(div, "display", "block");
	        dojo.replaceClass(linkClosed, "webfeed-link-open", "webfeed-link");  
	    } else {
	        dojo.style(div, "display", "none");
	        dojo.replaceClass(linkOpen, "webfeed-link", "webfeed-link-open");
	    }
	    resizeKCFrame();
	
	} else { // first opening of weblink
		if(linkClosed){
			dojo.replaceClass(linkClosed, "webfeed-link-open", "webfeed-link");
		} else if(linkOpen){
			dojo.replaceClass(linkOpen, "webfeed-link", "webfeed-link-open");
		}
	}
}

function getWebFeedListDiv(container) {
	var target = null;
	dojo.query(".webfeed-list-div").forEach(function(node) {
		if (node.parentNode === container.parentNode) {
			target = node;
		}		
	});		
	return target;
}

function getLoadingDiv(container) {
	var target = null;
	dojo.query(".webfeed-spin").forEach(function(node) {
		if (node.parentNode === container.parentNode) {
			target = node;
		}		
	});		
	return target;
}

function getElementByClassName(container, className) {
	var target = null;
	dojo.query("." + className).forEach(function(node) {
		if (node.parentNode === container.parentNode) {
			target = node;
		}		
	});		
	return target;
}

function showLoadingIndicator(container) {
	var div = document.createElement("div");
	div.setAttribute("class", "webfeed-spin");		
	container.parentNode.appendChild(div);	
}

function hidLoadingIndicator(container) {
	var div = getLoadingDiv(container);
	if (div) {
		container.parentNode.removeChild(div);
	}
}

function isLoading(container) {
	return getLoadingDiv(container);
}

function resizeKCFrame() {
	if (window.parent && window.parent.dijit && window.parent.dojo && window.parent.dojo.query(".topicIFrameContainer")) {
		var container = window.parent.dojo.query(".topicIFrameContainer");
		if (container && container[0]) {
			var kcFrameWidget = window.parent.dijit.byNode(container[0]);
			kcFrameWidget._onIFrameResize();
		}
	}
}

/**
 * Write error response to feed
 *
 */
function writeWebFeedErr(container, err, elementType) {
	if(err.responseText){
		var errElement = document.createElement(elementType);
		errElement.setAttribute("class", "webfeed-err");
		errElement.innerHTML = err.responseText;
		container.parentNode.appendChild(errElement);
		return;
	}
	console.err("Error response text empty !");
}


/**
 * Get webfeed-err element
 *
 */
function getWebFeedErr(container) {
	var target = null;
	dojo.query(".webfeed-err").forEach(function(node) {
		if (node.parentNode === container.parentNode) {
			target = node;
		}		
	});		
	return target;
}


/**
 * Remove webfeed-err element & toggle feed hide
 *
 */
function removeWebFeedErr(container) {
	var linkClosed = this.getElementByClassName(container, "webfeed-link");
	var linkOpen = this.getElementByClassName(container, "webfeed-link-open");
	var errElement = getWebFeedErr(container);
	if(errElement) {
		dojo.destroy(errElement);
		if (linkOpen) {
	    	dojo.replaceClass(linkOpen, "webfeed-link", "webfeed-link-open");
	    }
	    resizeKCFrame();
	}
}